package com.gic.haoban.manage.service.service.out.impl;

import java.util.Date;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.gic.api.base.commons.Page;
import com.gic.commons.util.EntityUtil;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.common.utils.PageUtil;
import com.gic.haoban.common.utils.StringUtil;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.service.entity.TabHaobanDepartment;
import com.gic.haoban.manage.service.entity.TabHaobanStaffDepartmentRelated;
import com.gic.haoban.manage.service.service.DepartmentService;
import com.gic.haoban.manage.service.service.StaffDepartmentRelatedService;
import com.github.pagehelper.PageHelper;

@Service
public class DepartmentApiServiceImpl implements DepartmentApiService {
	
	@Autowired
	private DepartmentService departmentService;
	@Autowired
	private StaffDepartmentRelatedService staffDepartmentService;

	@Override
	public List<DepartmentDTO> listByParentId(String parentId) {
		List<TabHaobanDepartment> list = departmentService.listByParentId(parentId);
		
		return EntityUtil.changeEntityListByJSON(DepartmentDTO.class, list);
	}

	@Override
	public DepartmentDTO selectById(String departmentId) {
		TabHaobanDepartment tab = departmentService.selectById(departmentId);
		return EntityUtil.changeEntityByJSON(DepartmentDTO.class, tab);
	}

	@Override
	public HaobanResponse add(DepartmentDTO department) {
		HaobanResponse hr = new HaobanResponse();
		hr.setErrorCode(1);
		//调微信的新增接口
		String wxDepartmentId = "";
		if(StringUtils.isBlank(wxDepartmentId)) {
			hr.setErrorCode(0);
			hr.setMessage("微信新增部门失败");
			return hr;
		}
		department.setWxDepartmentId(wxDepartmentId);
		String departmentId = departmentService.add(department);
		department.setDepartmentId(departmentId);
		hr.setResult(department);
		return hr;
	}

	@Override
	public HaobanResponse edit(DepartmentDTO department) {
		HaobanResponse hr = new HaobanResponse();
		hr.setErrorCode(1);
		//调微信的修改接口
		String wxDepartmentId = "";
		if(StringUtils.isBlank(wxDepartmentId)) {
			hr.setErrorCode(0);
			hr.setMessage("微信修改部门失败");
			return hr;
		}
		
		departmentService.edit(department);
		return hr;
	}

	@Override
	public HaobanResponse del(String departmentId) {
		HaobanResponse hr = new HaobanResponse();
		hr.setErrorCode(1);
		//调微信的新增接口
		String wxDepartmentId = "";
		if(StringUtils.isBlank(wxDepartmentId)) {
			hr.setErrorCode(0);
			hr.setMessage("微信删除部门失败");
			return hr;
		}
		List<TabHaobanDepartment> list = departmentService.listByParentId(departmentId);
		if(!list.isEmpty()) {
			hr.setErrorCode(0);
			hr.setMessage("存在子部门，删除部门失败");
			return hr;
		}
		
		List<TabHaobanStaffDepartmentRelated> staffList = staffDepartmentService.listByDepartmentId(departmentId);
		if(!staffList.isEmpty()) {
			hr.setErrorCode(0);
			hr.setMessage("存在成员，删除部门失败");
			return hr;
		}
		
		departmentService.del(departmentId);
		return hr;
	}

	@Override
	public DepartmentDTO selectByRelatedId(String relatedId) {
		TabHaobanDepartment tab = departmentService.selectByRelatedId(relatedId);
		return EntityUtil.changeEntityByJSON(DepartmentDTO.class, tab);
	}

	@Override
	public HaobanResponse recycle(String departmentId) {
		HaobanResponse hr = new HaobanResponse();
		hr.setErrorCode(1);
		departmentService.recycle(departmentId);
		return hr;
	}

	@Override
	public Page<DepartmentDTO> pageDepartmentByParams(BasePageInfo pageInfo, String wxEnterpriseId, String keyword,
			Integer storeFlag, Integer recycleFlag) {
		PageHelper.startPage(pageInfo.getPageNum(), pageInfo.getPageSize());
		return  PageUtil.changePageHelperToCurrentPage(departmentService.pageDepartmentByParams(wxEnterpriseId,keyword,storeFlag,recycleFlag),DepartmentDTO.class);
	}

	@Override
	public HaobanResponse repairRecycle(String departmentId) {
		HaobanResponse hr = new HaobanResponse();
		hr.setErrorCode(0);
		departmentService.repairRecycle(departmentId);
		return hr;
		
	}

}
