package com.gic.haoban.manage.web.controller;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONArray;
import com.gic.api.base.commons.Page;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.service.DepartmentService;
import com.gic.enterprise.api.service.StoreService;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.base.api.common.Constant;
import com.gic.haoban.common.utils.AuthRequestUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.qo.DepartmentAddQO;
import com.gic.haoban.manage.web.qo.DepartmentEditQO;
import com.gic.haoban.manage.web.vo.LoginVO;

@RestController
public class DepartmentContoller extends WebBaseController{
	@Autowired
	private DepartmentApiService departmentApiService;
	@Autowired
	private DepartmentService departmentService;
	
	@Autowired
	private StoreService storeService;
	
	@RequestMapping("department-list")
	public HaobanResponse departmentList(String parentId) {
		List<DepartmentDTO> list = departmentApiService.listByParentId(parentId);
		
		return resultResponse(HaoBanErrCode.ERR_1,list);
		
	}
	
	@RequestMapping("department-add")
	public HaobanResponse departmentAdd(String parentId,String departmentName) {
		DepartmentDTO dto = departmentApiService.selectById(parentId);
		if(dto == null || dto.getStatusFlag() == 0) {
			return resultResponse(HaoBanErrCode.ERR_10001);
		}
		if(dto.getIsStore() == 1) {
			return resultResponse(HaoBanErrCode.ERR_10002);
		}
		DepartmentDTO department = new DepartmentDTO();
		department.setParentDepartmentId(parentId);
		department.setDepartmentName(departmentName);
		department.setWxEnterpriseId(dto.getWxDepartmentId());
		department.setChainId(dto.getChainId() + Constant.ID_SEPARATOR + dto.getDepartmentId());
		department.setIsStore(0);
		departmentApiService.add(department);
	
		return resultResponse(HaoBanErrCode.ERR_1);
		
	}
	
	@RequestMapping("department-edit")
	public HaobanResponse departmentEdit(String departmentId,String departmentName) {
		DepartmentDTO dto = departmentApiService.selectById(departmentId);
		if(dto == null || dto.getStatusFlag() == 0) {
			return resultResponse(HaoBanErrCode.ERR_10001);
		}
		dto.setDepartmentName(dto.getDepartmentName());
		departmentApiService.edit(dto);
	
		return resultResponse(HaoBanErrCode.ERR_1);
		
	}
	
	@RequestMapping("department-sel")
	public HaobanResponse departmentSel(String departmentId) {
		DepartmentDTO dto = departmentApiService.selectById(departmentId);
		if(dto == null || dto.getStatusFlag() == 0) {
			return resultResponse(HaoBanErrCode.ERR_10003);
		}
	
		return resultResponse(HaoBanErrCode.ERR_1,dto);
		
	}
	
	@RequestMapping("department-del")
	public HaobanResponse departmentDel(String departmentId) {
		DepartmentDTO dto = departmentApiService.selectById(departmentId);
		if(dto == null || dto.getStatusFlag() == 0) {
			return resultResponse(HaoBanErrCode.ERR_10003);
		}
		HaobanResponse hr;
		if(StringUtils.isBlank(dto.getRelatedId())) {
			hr = departmentApiService.del(departmentId);
		}else {
			hr =  departmentApiService.recycle(departmentId);
		}
		
		if(hr.getErrorCode() == 0) {
			return resultResponse(HaoBanErrCode.ERR_0, hr.getMessage());
		}
		return resultResponse(HaoBanErrCode.ERR_1);
		
	}
	
	@RequestMapping("department-batch-sync")
	public HaobanResponse departmentBatchSync(String editDepartment,String delDepartmentIds,String addDepartment) {
		if(StringUtils.isNotBlank(addDepartment)) {
			List<DepartmentAddQO> list = JSONArray.parseArray(addDepartment, DepartmentAddQO.class);
			for (DepartmentAddQO departmentAddQO : list) {
				String parentId = departmentAddQO.getParentId();
				DepartmentDTO dto = departmentApiService.selectById(parentId);
				if(dto == null || dto.getStatusFlag() == 0) {
					continue;
				}
				if(dto.getIsStore() == 1) {
					continue;
				}
				DepartmentDTO department = new DepartmentDTO();
				department.setParentDepartmentId(parentId);
				department.setWxDepartmentId(dto.getWxDepartmentId());
				department.setDepartmentName(departmentAddQO.getDepartmentName());
				department.setChainId(dto.getChainId() + Constant.ID_SEPARATOR + dto.getDepartmentId());
				department.setIsStore(0);
				department.setIsStore(departmentAddQO.getStoreFlag());
				department.setLevel(dto.getLevel() + 1);
				HaobanResponse hr = departmentApiService.add(department);
				if(hr.getErrorCode() != 1) {
					continue;
				}
				DepartmentDTO departmentAdd = (DepartmentDTO) hr.getResult();
				String departmentId = departmentAdd.getDepartmentId();
				
				String sonDepartment = departmentAddQO.getSonDepartment();
				handler(sonDepartment,departmentId);
				
			}
		}
		
		if(StringUtils.isNotBlank(editDepartment)) {
			List<DepartmentEditQO> list = JSONArray.parseArray(editDepartment, DepartmentEditQO.class);
			for (DepartmentEditQO departmentQO : list) {
				String parentId = departmentQO.getCurrDepartment();
				DepartmentDTO parent = departmentApiService.selectById(parentId);
				if(parent == null || parent.getStatusFlag() == 0) {
					continue;
				}
				DepartmentDTO department = departmentApiService.selectById(parentId);
				department.setParentDepartmentId(parentId);
				department.setDepartmentName(departmentQO.getDepartmentName());
				department.setChainId(parent.getChainId() + Constant.ID_SEPARATOR + parent.getDepartmentId());
				department.setLevel(parent.getLevel() + 1);
				HaobanResponse hr = departmentApiService.edit(department);
				
			}
			
		}
		
		if(StringUtils.isNotBlank(delDepartmentIds)) {
			String[] delIds = delDepartmentIds.split(",");
			for (String string : delIds) {
				DepartmentDTO dto = departmentApiService.selectById(string);
				if(dto == null || dto.getStatusFlag() == 0) {
					continue;
				}
				if(StringUtils.isBlank(dto.getRelatedId())) {
					departmentApiService.del(string);
				}else {
					departmentApiService.recycle(string);
				}
			}
		}
		
		return resultResponse(HaoBanErrCode.ERR_1);
		
	}
	
	@RequestMapping("unbind-department-list")
	public HaobanResponse unbindDepartmentList(String departmentId,String enterpriseId) {
		List<String> list = new ArrayList<String>();
		list.add(departmentId);
		List<com.gic.enterprise.api.dto.DepartmentDTO> departmentList = departmentService.getDeptmentByPids(list);
		
		List<StoreDTO> storeList = storeService.listStoreByStoreGroupId(departmentId);
		
		List<DepartmentDTO> dtoList = new ArrayList<DepartmentDTO>();
		for (com.gic.enterprise.api.dto.DepartmentDTO departmentDTO : departmentList) {
			DepartmentDTO dto = departmentApiService.selectByRelatedId(departmentDTO.getDepartId());
			if(dto == null) {
				DepartmentDTO unBindDTO = new DepartmentDTO();
				unBindDTO.setRelatedId(departmentDTO.getDepartId());
				unBindDTO.setIsStore(0);
				unBindDTO.setDepartmentName(departmentDTO.getDepartName());
				dtoList.add(unBindDTO);
			}
		}
		
		for (StoreDTO storeDTO : storeList) {
			DepartmentDTO dto = departmentApiService.selectByRelatedId(storeDTO.getStoreId());
			if(dto == null) {
				DepartmentDTO unBindDTO = new DepartmentDTO();
				unBindDTO.setRelatedId(storeDTO.getStoreId());
				unBindDTO.setIsStore(0);
				unBindDTO.setDepartmentName(storeDTO.getStoreName());
				dtoList.add(unBindDTO);
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1,dtoList);
		
	}
	
	
	@RequestMapping("department-recycle-list")
	public HaobanResponse departmentRecycleList(String keyword,Integer storeFlag,BasePageInfo pageInfo) {
		LoginVO login =  (LoginVO) AuthRequestUtil.getAppLoginUser();
		String wxEnterpriseId  = login.getWxEnterpriseId();
		Integer recycleFlag = 1;
		Page<DepartmentDTO> page = departmentApiService.pageDepartmentByParams(pageInfo,wxEnterpriseId,keyword,storeFlag,recycleFlag);
		return resultResponse(HaoBanErrCode.ERR_1,page);
		
	}
	
	@RequestMapping("department-repair")
	public HaobanResponse departmentRepair(String departmentId) {
		DepartmentDTO dto = departmentApiService.selectById(departmentId);
		if(dto == null || dto.getStatusFlag() == 0) {
			return resultResponse(HaoBanErrCode.ERR_10003);
		}
		departmentApiService.repairRecycle(departmentId);
		return resultResponse(HaoBanErrCode.ERR_1);
		
	}
	
	

	private void handler(String sonDepartment, String parentId) {
		if(StringUtils.isNotBlank(sonDepartment)) {
			List<DepartmentAddQO> list = JSONArray.parseArray(sonDepartment, DepartmentAddQO.class);
			for (DepartmentAddQO departmentAddQO : list) {
				
				String sonParentId = "";
				DepartmentDTO dto = departmentApiService.selectById(parentId);
				if(dto == null || dto.getStatusFlag() == 0) {
					continue;
				}
				if(dto.getIsStore() == 1) {
					continue;
				}
				String departmentId = departmentAddQO.getDepartmentId();
				//在部门下新增部门
				if(StringUtils.isBlank(departmentId)) {
					DepartmentDTO department = new DepartmentDTO();
					department.setParentDepartmentId(parentId);
					department.setWxEnterpriseId(dto.getWxEnterpriseId());
					department.setDepartmentName(departmentAddQO.getDepartmentName());
					department.setChainId(dto.getChainId() + Constant.ID_SEPARATOR + dto.getDepartmentId());
					department.setIsStore(0);
					department.setIsStore(departmentAddQO.getStoreFlag());
					department.setLevel(dto.getLevel() + 1);
					department.setRelatedId(departmentAddQO.getRelatedId());
					HaobanResponse hr = departmentApiService.add(department);
					if(hr.getErrorCode() != 1) {
						continue;
					}
					DepartmentDTO departmentAdd = (DepartmentDTO) hr.getResult();
					sonParentId = departmentAdd.getDepartmentId();
				//别的部门调整过来的
				}else {
					DepartmentDTO department = departmentApiService.selectById(departmentId);
					if(department == null || department.getStatusFlag() == 0) {
						continue;
					}
					department.setParentDepartmentId(parentId);
					department.setParentDepartmentId(parentId);
					department.setDepartmentName(departmentAddQO.getDepartmentName());
					department.setChainId(dto.getChainId() + Constant.ID_SEPARATOR + dto.getDepartmentId());
					HaobanResponse hr = departmentApiService.edit(department);
					if(hr.getErrorCode() != 1) {
						continue;
					}
					DepartmentDTO departmentEdit = (DepartmentDTO) hr.getResult();
					sonParentId = departmentEdit.getDepartmentId();
				}
				
				sonDepartment = departmentAddQO.getSonDepartment();
				handler(sonDepartment,sonParentId);
				
			}
			
		}
		
	}


}
