package com.gic.haoban.manage.web.init;

import com.gic.dict.api.dto.GlobalDictMap;
import com.gic.dict.api.service.ManagerDictService;
import com.gic.quartz.api.dto.QuartzTaskDTO;
import com.gic.quartz.api.service.QuartzService;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

@Component
public class MyApplicationContextAware implements ApplicationContextAware {
    private Logger log = LogManager.getLogger(MyApplicationContextAware.class);

    private static ApplicationContext applicationContext;

    @Autowired
    private ManagerDictService managerDictService;
    
    @Autowired
	private QuartzService quartzService; 

    @Override
    public void setApplicationContext(ApplicationContext appContext) throws BeansException {
        applicationContext = appContext;
        GlobalDictMap.countyMap = managerDictService.getCountysMap();
        GlobalDictMap.cityMap = managerDictService.getCitysMap();
        GlobalDictMap.provinceMap = managerDictService.getProvincesMap();
        GlobalDictMap.dictMap = managerDictService.getDictList();
        GlobalDictMap.storeCategoryDictMap = managerDictService.getStoreCategoryDictList();
        log.info("数据字典放入缓存");
        
        
        QuartzTaskDTO taskDTO =buildQuartzTaskDTO("haoban-dismiss-enterprise-time");
		taskDTO.setTaskParam("");
		taskDTO.setTaskStatus(1);
		taskDTO.setTaskTimeInfo("0 30 0 * * *");
//		taskDTO.setTaskTimeInfo("0 0/1 * * * *");
		quartzService.addOrUpdateQuartzTask(taskDTO);
		
		
		QuartzTaskDTO task =buildSendReportQuartzTaskDTO("haoban-send-report");
		task.setTaskParam("");
		task.setTaskStatus(1);
		task.setTaskTimeInfo("0 0 12 1 * 0");
		quartzService.addOrUpdateQuartzTask(taskDTO);
		
		QuartzTaskDTO memberExportTask =buildMemberExportQuartzTaskDTO("haoban-member-export");
		memberExportTask.setTaskParam("-1");
		memberExportTask.setTaskStatus(1);
		memberExportTask.setTaskTimeInfo("0 0/15 * * * *");
		quartzService.addOrUpdateQuartzTask(memberExportTask);
    }
    
    private QuartzTaskDTO buildMemberExportQuartzTaskDTO(String id) {
    	  QuartzTaskDTO taskDTO = new QuartzTaskDTO();
          taskDTO.setReferId(id);
          taskDTO.setTaskMethod("quartzMemberExport");
          taskDTO.setTaskService("com.gic.haoban.app.member.service.api.service.MemberExportApiService");
          return taskDTO;
	}

	private QuartzTaskDTO buildQuartzTaskDTO(String id){
        QuartzTaskDTO taskDTO = new QuartzTaskDTO();
        taskDTO.setReferId(id);
        taskDTO.setTaskMethod("taskDismissEnterprise");
        taskDTO.setTaskService("com.gic.haoban.manage.api.service.EnterpriseService");
        return taskDTO;
    }
    
    private QuartzTaskDTO buildSendReportQuartzTaskDTO(String id){
        QuartzTaskDTO taskDTO = new QuartzTaskDTO();
        taskDTO.setReferId(id);
        taskDTO.setTaskMethod("sendReportMessage");
        taskDTO.setTaskService("com.gic.haoban.data.api.service.SendReportMessageApiService");
        return taskDTO;
    }

}
