package com.gic.haoban.manage.web.interceptor;

import com.alibaba.fastjson.JSONObject;
import com.gic.haoban.auth.api.anno.MenuCheck;
import com.gic.haoban.auth.api.dto.UserRightDetailDTO;
import com.gic.haoban.auth.api.enums.RoleCodeEnum;
import com.gic.haoban.auth.api.service.ClerkRightManageService;
import com.gic.haoban.common.utils.AuthRequestUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Map;

/**
 * Created 2018/7/20.
 *
 * @author hua
 */
public class WebInterceptor extends HandlerInterceptorAdapter {

    private static Logger logger= LoggerFactory.getLogger(WebInterceptor.class);

    @Autowired
    private ClerkRightManageService clerkRightManageService;


    private void errorResult(HttpServletResponse httpServletResponse, HaoBanErrCode errCode) {
        HaobanResponse response = new HaobanResponse();
        response.setErrorCode(errCode.getCode());
        response.setMessage(errCode.getMsg());
        PrintWriter writer = null;
        try {
            httpServletResponse.setHeader("Content-type", "application/json;charset=UTF-8");
            writer = httpServletResponse.getWriter();
            writer.append(JSONObject.toJSONString(response));
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    @Override
    public boolean preHandle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o) throws Exception {
        String requestURI = httpServletRequest.getRequestURI();
        logger.info("post-url:{}", requestURI);
        Map<String, String[]> parameterMap = httpServletRequest.getParameterMap();
        logger.info("post-params:{}", JSONObject.toJSONString(parameterMap));
        UserRightDetailDTO loginUser = (UserRightDetailDTO) AuthRequestUtil.getSessionUser();

        if (loginUser == null) {
            this.errorResult(httpServletResponse, HaoBanErrCode.ERR_4);
            logger.info("用户不存在!");
            return false;
        }
        HandlerMethod method = null;
        if (o instanceof HandlerMethod) {
            method = (HandlerMethod) (o);
        }
        if (method == null) {
            return true;
        }
        MenuCheck methodAnnotation = method.getMethodAnnotation(MenuCheck.class);
        if (StringUtils.isNotBlank(loginUser.getEnterpriseId())) {
            httpServletRequest.setAttribute("enterpriseId", loginUser.getEnterpriseId());
        }
        if (StringUtils.isNotBlank(loginUser.getUserId())) {
            httpServletRequest.setAttribute("clerkId", loginUser.getUserId());
        }
        if (null != methodAnnotation) {
            String value = methodAnnotation.value();
            RoleCodeEnum[] roleCodes = methodAnnotation.roleCodes();
            boolean b = true;
            //权限判断
            if (StringUtils.isNotBlank(value)) {
                b = loginUser.checkRight(value);
            }
            //角色判读
            if (b) {
                if (roleCodes.length > 0) {
                    b = Arrays.stream(roleCodes).anyMatch(codeEnum -> loginUser.checkRole(codeEnum.getCode()));
                }
            }
            if (!b) {
                logger.info("缺少权限");
                errorResult(httpServletResponse, HaoBanErrCode.ERR_7);
            }
            return b;
        }
        return true;
    }

    @Override
    public void postHandle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o, ModelAndView modelAndView) throws Exception {
        logger.info("end");
    }

    @Override
    public void afterCompletion(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o, Exception e) throws Exception {
        logger.info("end");
    }
}
